@@ -24,10 +24,11 @@ from pathlib import Path
 from typing import Optional
 
 import click
-from aea.cli.utils.click_utils import PublicIdParameter
+from aea.cli.utils.click_utils import PublicIdParameter, reraise_as_click_exception
 from aea.configurations.data_types import PublicId
 
 from autonomy.configurations.loader import load_service_config
+from autonomy.deploy.image import ImageBuildFailed
 from autonomy.deploy.image import build_image as _build_image
 
 
@@ -54,17 +55,13 @@ def build_image(
 ) -> None:
     """Build runtime images for autonomous agents."""
 
-    try:
+    with reraise_as_click_exception(FileNotFoundError):
         if agent is None:
             service_dir = Path(service_dir or Path.cwd()).absolute()
             service = load_service_config(service_dir)
             agent = service.agent
-    except FileNotFoundError as e:
-        raise click.ClickException(
-            "Service configuration not found the current directory"
-        ) from e
 
-    try:
+    with reraise_as_click_exception(ImageBuildFailed):
         click.echo(f"Building image with agent: {agent}\n")
         _build_image(
             agent=agent,
@@ -72,5 +69,3 @@ def build_image(
             dev=dev,
             version=version,
         )
-    except Exception as e:  # pylint: disable=broad-except
-        raise click.ClickException(str(e)) from e
