@@ -1607,6 +1607,17 @@ class BaseBehaviour(AsyncBehaviour, IPFSBehaviour, CleanUpBehaviour, ABC):
             return RPCResponseStatus.ALREADY_KNOWN
         return RPCResponseStatus.UNCLASSIFIED_ERROR
 
+    @property
+    def hard_reset_sleep(self) -> float:
+        """
+        Amount of time to sleep before and after performing a hard reset.
+
+        We sleep for half the observation interval as there are no immediate transactions on either side of the reset.
+
+        :returns: the amount of time to sleep in seconds
+        """
+        return self.params.observation_interval / 2
+
     def _start_reset(self) -> Generator:
         """Start tendermint reset.
 
@@ -1616,10 +1627,7 @@ class BaseBehaviour(AsyncBehaviour, IPFSBehaviour, CleanUpBehaviour, ABC):
         :yield: None
         """
         if self._check_started is None and not self._is_healthy:
-            # we do the reset in the middle of the pause as there are no immediate transactions on either side of the reset
-            yield from self.wait_from_last_timestamp(
-                self.params.observation_interval / 2
-            )
+            yield from self.wait_from_last_timestamp(self.hard_reset_sleep)
             self._check_started = datetime.datetime.now()
             self._timeout = self.params.max_healthcheck
             self._is_healthy = False
@@ -1681,7 +1689,7 @@ class BaseBehaviour(AsyncBehaviour, IPFSBehaviour, CleanUpBehaviour, ABC):
             ("initial_height", initial_height),
         ]
 
-    def reset_tendermint_with_wait(
+    def reset_tendermint_with_wait(  # pylint: disable= too-many-locals
         self,
         on_startup: bool = False,
     ) -> Generator[None, None, bool]:
@@ -1696,34 +1704,43 @@ class BaseBehaviour(AsyncBehaviour, IPFSBehaviour, CleanUpBehaviour, ABC):
                 f"Resetting tendermint node at end of period={self.synchronized_data.period_count}."
             )
 
+            backup_blockchain = self.context.state.round_sequence.blockchain
+            self.context.state.round_sequence.reset_blockchain()
+            reset_params = self._get_reset_params(on_startup)
             request_message, http_dialogue = self._build_http_request_message(
                 "GET",
                 self.params.tendermint_com_url + "/hard_reset",
-                parameters=self._get_reset_params(on_startup),
+                parameters=reset_params,
             )
             result = yield from self._do_request(request_message, http_dialogue)
             try:
                 response = json.loads(result.body.decode())
                 if response.get("status"):
                     self.context.logger.info(response.get("message"))
-                    self.context.logger.info(
-                        "Resetting tendermint node successful! Resetting local blockchain."
-                    )
-                    self.context.state.round_sequence.reset_blockchain(
-                        response.get("is_replay", False)
-                    )
+                    self.context.logger.info("Resetting tendermint node successful!")
+                    is_replay = response.get("is_replay", False)
+                    if is_replay:
+                        # in case of replay, the local blockchain should be set up differently.
+                        self.context.state.round_sequence.reset_blockchain(
+                            is_replay=is_replay, is_init=True
+                        )
                     self.context.state.round_sequence.abci_app.cleanup(
                         self.params.cleanup_history_depth,
                         self.params.cleanup_history_depth_current,
                     )
-
                     for handler_name in self.context.handlers.__dict__.keys():
                         dialogues = getattr(self.context, f"{handler_name}_dialogues")
                         dialogues.cleanup()
-
+                    # in case of successful reset we store the reset params in the shared state,
+                    # so that in the future if the communication with tendermint breaks, and we need to
+                    # perform a hard reset to restore it, we can use these as the right ones
+                    cast(
+                        SharedState, self.context.state
+                    ).last_reset_params = reset_params
                     self._end_reset()
                 else:
                     msg = response.get("message")
+                    self.context.state.round_sequence.blockchain = backup_blockchain
                     self.context.logger.error(f"Error resetting: {msg}")
                     yield from self.sleep(self.params.sleep_time)
                     return False
@@ -1731,6 +1748,7 @@ class BaseBehaviour(AsyncBehaviour, IPFSBehaviour, CleanUpBehaviour, ABC):
                 self.context.logger.error(
                     "Error communicating with tendermint com server."
                 )
+                self.context.state.round_sequence.blockchain = backup_blockchain
                 yield from self.sleep(self.params.sleep_time)
                 return False
 
@@ -1757,7 +1775,7 @@ class BaseBehaviour(AsyncBehaviour, IPFSBehaviour, CleanUpBehaviour, ABC):
         self.context.logger.info(
             "local height == remote height; continuing execution..."
         )
-        yield from self.wait_from_last_timestamp(self.params.observation_interval / 2)
+        yield from self.wait_from_last_timestamp(self.hard_reset_sleep)
         return True
 
 
@@ -1766,6 +1784,7 @@ class TmManager(BaseBehaviour, ABC):
 
     behaviour_id = "tm_manager"
     _active_generator: Optional[Generator] = None
+    _hard_reset_sleep = 10.0  # 10s
 
     def async_act(self) -> Generator:  # type: ignore
         """The behaviour act."""
@@ -1782,6 +1801,17 @@ class TmManager(BaseBehaviour, ABC):
         """This method returns whether there is an active fix being applied."""
         return self._active_generator is not None
 
+    @property
+    def hard_reset_sleep(self) -> float:
+        """
+        Amount of time to sleep before and after performing a hard reset.
+
+        We don't need to wait for half the observation interval, like in normal cases where we perform a hard reset.
+
+        :returns: the amount of time to sleep in seconds
+        """
+        return self._hard_reset_sleep
+
     def _handle_unhealthy_tm(self) -> Generator:
         """This method handles the case when the tendermint node is unhealthy."""
         self.context.logger.warning(
@@ -1812,6 +1842,19 @@ class TmManager(BaseBehaviour, ABC):
 
         self.context.logger.info("Tendermint reset was successfully performed. ")
 
+    def _get_reset_params(self, default: bool) -> Optional[List[Tuple[str, str]]]:
+        """
+        Get the parameters for a hard reset request when trying to recover agent <-> tendermint communication.
+
+        :param default: ignored for this use case.
+        :returns: the reset params.
+        """
+        # we get the params from the latest successful reset, if they are not available,
+        # i.e. no successful reset has been performed, we return None.
+        # Returning None means default params will be used.
+        reset_params = cast(SharedState, self.context.state).last_reset_params
+        return reset_params
+
     def try_fix(self) -> None:
         """This method tries to fix an unhealthy node."""
         if self._active_generator is None:
