@@ -20,18 +20,15 @@
 
 """Test the `rounds` test tool module of the skill."""
 
-
-import os
 import re
 from enum import Enum
 from typing import Any, FrozenSet, Generator, List, Optional, Tuple, Type, cast
 from unittest.mock import MagicMock
 
 import pytest
-from hypothesis import given, settings
+from hypothesis import given
 from hypothesis import strategies as st
 
-from packages.valory.skills.abstract_round_abci import CI
 from packages.valory.skills.abstract_round_abci.base import (
     AbciAppDB,
     BaseSynchronizedData,
@@ -63,10 +60,6 @@ from packages.valory.skills.abstract_round_abci.tests.test_common import last_it
 # this is how many times we need to iterate before reaching the last iteration for a base test.
 BASE_TEST_GEN_ITERATIONS = 4
 
-running_on_ci = os.getenv(CI)
-if running_on_ci:
-    settings.load_profile(CI)
-
 
 def test_get_participants() -> None:
     """Test `get_participants`."""
