@@ -45,6 +45,7 @@ from packages.valory.skills.abstract_round_abci.behaviour_utils import (
 from packages.valory.skills.abstract_round_abci.test_tools.base import (
     FSMBehaviourBaseCase,
 )
+from packages.valory.skills.registration_abci import PUBLIC_ID
 from packages.valory.skills.registration_abci.behaviours import (
     RegistrationBaseBehaviour,
     RegistrationBehaviour,
@@ -77,6 +78,13 @@ DUMMY_VALIDATOR_CONFIG = {
 }
 
 
+def test_skill_public_id() -> None:
+    """Test skill module public ID"""
+
+    assert PUBLIC_ID.name == Path(__file__).parents[1].name
+    assert PUBLIC_ID.author == Path(__file__).parents[3].name
+
+
 def consume(iterator: Iterable) -> None:
     """Consume the iterator"""
     collections.deque(iterator, maxlen=0)
@@ -197,6 +205,11 @@ class TestRegistrationStartupBehaviour(RegistrationAbciBaseCase):
             return_value=ON_CHAIN_SERVICE_ID,
         )
 
+    @property
+    def mocked_yield_from_sleep(self) -> mock._patch:
+        """Mock yield from sleep"""
+        return mock.patch.object(self.behaviour.current_behaviour, "sleep")
+
     # mock contract calls
     def mock_is_correct_contract(self, error_response: bool = False) -> None:
         """Mock service registry contract call to for contract verification"""
@@ -336,9 +349,9 @@ class TestRegistrationStartupBehaviour(RegistrationAbciBaseCase):
 
     def test_no_contract_address(self, caplog: LogCaptureFixture) -> None:
         """Test service registry contract address not provided"""
-        with caplog.at_level(
-            logging.INFO,
-            logger=self.logger,
+        with as_context(
+            caplog.at_level(logging.INFO, logger=self.logger),
+            self.mocked_yield_from_sleep,
         ):
             self.behaviour.act_wrapper()
             self.mock_get_local_tendermint_params()
@@ -357,6 +370,7 @@ class TestRegistrationStartupBehaviour(RegistrationAbciBaseCase):
         with as_context(
             caplog.at_level(logging.INFO, logger=self.logger),
             self.mocked_service_registry_address,
+            self.mocked_yield_from_sleep,
         ):
             self.behaviour.act_wrapper()
             self.mock_get_local_tendermint_params(valid_response=valid_response)
@@ -472,6 +486,7 @@ class TestRegistrationStartupBehaviour(RegistrationAbciBaseCase):
             caplog.at_level(logging.INFO, logger=self.logger),
             self.mocked_service_registry_address,
             self.mocked_on_chain_service_id,
+            self.mocked_yield_from_sleep,
         ):
             self.behaviour.act_wrapper()
             self.mock_get_local_tendermint_params()
