@@ -18,6 +18,7 @@
 # ------------------------------------------------------------------------------
 
 """This module contains the data classes for the reset_pause_abci application."""
+
 from enum import Enum
 from typing import Dict, Optional, Set, Tuple, Type
 
@@ -50,6 +51,7 @@ class ResetAndPauseRound(CollectSameUntilThresholdRound):
     allowed_tx_type = ResetPausePayload.transaction_type
     payload_attribute = "period_count"
     _allow_rejoin_payloads = True
+    synchronized_data_class = BaseSynchronizedData
 
     def end_block(self) -> Optional[Tuple[BaseSynchronizedData, Event]]:
         """Process the end of the block."""
@@ -87,34 +89,26 @@ class FinishedResetAndPauseErrorRound(DegenerateRound):
     round_id = "finished_reset_pause_error"
 
 
-class ResetPauseABCIApp(AbciApp[Event]):
-    """ResetPauseABCIApp
+class ResetPauseAbciApp(AbciApp[Event]):
+    """ResetPauseAbciApp
 
-    Initial round: RegistrationRound
+    Initial round: ResetAndPauseRound
 
-    Initial states: {RegistrationRound}
+    Initial states: {ResetAndPauseRound}
 
     Transition states:
+        0. ResetAndPauseRound
+            - done: 1.
+            - reset and pause timeout: 2.
+            - no majority: 2.
+        1. FinishedResetAndPauseRound
+        2. FinishedResetAndPauseErrorRound
 
-    0. ResetAndPauseRound
-        - done: 1.
-        - reset timeout: 0.
-        - no majority: 0.
-    1. FinishedResetAndPauseRound
-    2. FinishedResetAndPauseErrorRound
-
-    Initial states: {
-        ResetAndPauseRound,
-    }
-
-    Final states: {
-        FinishedResetAndPauseRound,
-        FinishedResetAndPauseErrorRound,
-    }
+    Final states: {FinishedResetAndPauseErrorRound, FinishedResetAndPauseRound}
 
     Timeouts:
         round timeout: 30.0
-        reset timeout: 30.0
+        reset and pause timeout: 30.0
     """
 
     initial_round_cls: Type[AbstractRound] = ResetAndPauseRound
