@@ -29,7 +29,7 @@ parse_logs  # unused function (autonomy/cli/analyse.py:74)
 HARDHAT_IMAGE_NAME  # unused variable (autonomy/constants.py:25)
 is_transition_func_total  # unused method (autonomy/analyse/abci/app_spec.py:119)
 get_transitions  # unused method (autonomy/analyse/abci/app_spec.py:134)
-generate_abci_app_specs  # unused function (autonomy/cli/analyse.py:52)
+abci_app_specs  # unused function (autonomy/cli/analyse.py:52)
 check_abci_app_specs  # unused function (autonomy/cli/analyse.py:79)
 run_handler_check  # unused function (autonomy/cli/analyse.py:159)
 dump_json  # unused method (autonomy/analyse/abci/app_spec.py:159)
@@ -136,3 +136,4 @@ identity  # unused function (autonomy/test_tools/helpers/base.py:87)
 skip_docker_tests  # unused variable (autonomy/test_tools/docker/base.py:40)
 run_service_locally  # unused function (autonomy.cli.develop.run_service_locally)
 lock_packages  # unused function (autonomy/cli/packages.py:33)
+PathArgument  # unused class (autonomy/cli/utils/click_utils.py:91)
