@@ -30,6 +30,7 @@ from typing import Any, List, Tuple, cast
 
 import pytest
 import yaml
+from aea.exceptions import AEAValidationError
 
 from autonomy.configurations.base import Service
 from autonomy.configurations.validation import ConfigValidator
@@ -38,7 +39,7 @@ from autonomy.constants import (
     HARDHAT_IMAGE_VERSION,
     TENDERMINT_IMAGE_VERSION,
 )
-from autonomy.deploy.base import BaseDeploymentGenerator, ServiceSpecification
+from autonomy.deploy.base import BaseDeploymentGenerator, ServiceBuilder
 from autonomy.deploy.generators.docker_compose.base import DockerComposeGenerator
 from autonomy.deploy.generators.kubernetes.base import KubernetesGenerator
 
@@ -68,31 +69,32 @@ fingerprint_ignore_patterns: []
 
 LIST_SKILL_OVERRIDE: str = """public_id: valory/price_estimation_abci:0.1.0
 type: skill
-models:
-  0:
-    - price_api:
-        args:
-          url: 'https://api.coingecko.com/api/v3/simple/price'
-          api_id: 'coingecko'
-          parameters:
-          - - ids
-            - bitcoin
-          - - vs_currencies
-            - usd
-          response_key: 'bitcoin:usd'
-          headers: ~
-  1:
-    - price_api:
-        args:
-          url: 'https://api.coingecko.com/api/v3/simple/price'
-          api_id: 'coingecko'
-          parameters:
-          - - ids
-            - bitcoin
-          - - vs_currencies
-            - usd
-          response_key: 'bitcoin:usd'
-          headers: ~
+0:
+  models:
+    price_api:
+      args:
+        url: 'https://api.coingecko.com/api/v3/simple/price'
+        api_id: 'coingecko'
+        parameters:
+        - - ids
+          - bitcoin
+        - - vs_currencies
+          - usd
+        response_key: 'bitcoin:usd'
+        headers: ~
+1:
+  models:
+    price_api:
+      args:
+        url: 'https://api.coingecko.com/api/v3/simple/price'
+        api_id: 'coingecko'
+        parameters:
+        - - ids
+          - bitcoin
+        - - vs_currencies
+          - usd
+        response_key: 'bitcoin:usd'
+        headers: ~
 """
 SKILL_OVERRIDE: str = """public_id: valory/price_estimation_abci:0.1.0
 type: skill
@@ -200,13 +202,13 @@ class BaseDeploymentTests(ABC, CleanDirectoryClass):
 
     def load_deployer_and_app(
         self, app: str, deployer: BaseDeploymentGenerator
-    ) -> Tuple[BaseDeploymentGenerator, ServiceSpecification]:
+    ) -> Tuple[BaseDeploymentGenerator, ServiceBuilder]:
         """Handles loading the 2 required instances"""
-        app_instance = ServiceSpecification(
-            service_path=Path(app).parent,
-            keys=DEFAULT_KEY_PATH,
+        app_instance = ServiceBuilder.from_dir(
+            path=Path(app).parent,
+            keys_file=DEFAULT_KEY_PATH,
         )
-        instance = deployer(service_spec=app_instance, build_dir=self.temp_dir.name)  # type: ignore
+        instance = deployer(service_builder=app_instance, build_dir=self.temp_dir.name)  # type: ignore
         return instance, app_instance
 
 
@@ -254,7 +256,7 @@ class TestDeploymentGenerators(BaseDeploymentTests):
     """Test functionality of the deployment generators."""
 
     def test_generates_agent_for_all_valory_apps(self) -> None:
-        """Test generator functions with all valory apps."""
+        """Test generator functions with all agent services."""
         for deployment_generator in deployment_generators:
             for spec in get_valid_deployments():
                 spec_path = self.write_deployment(spec)
@@ -265,7 +267,7 @@ class TestDeploymentGenerators(BaseDeploymentTests):
                 assert len(res) >= 1
 
     def test_generates_agents_for_all_valory_apps(self) -> None:
-        """Test functionality of the valory deployment generators."""
+        """Test functionality of the deployment generators."""
         for deployment_generator in deployment_generators:
             for spec in get_valid_deployments():
                 spec_path = self.write_deployment(spec)
@@ -324,9 +326,9 @@ class TestCliTool(BaseDeploymentTests):
                 "---\n".join([BASE_DEPLOYMENT, SKILL_OVERRIDE, SKILL_OVERRIDE])
             )
             with pytest.raises(
-                ValueError,
+                AEAValidationError,
                 match=re.escape(
-                    "Configuration of component (skill, valory/price_estimation_abci:0.1.0) occurs more than once"
+                    "Overrides for component (skill, valory/price_estimation_abci:0.1.0) are defined more than once"
                 ),
             ):
                 self.load_deployer_and_app(spec_path, deployment_generator)
